% taylor1n.m - Taylor n-bar line source array design
%
% Usage: [a, dph] = taylor1n(d, ph0, N, R, nbar)
%
% d   = element spacing in units of lambda
% ph0 = beam angle in degrees (broadside ph0=90)
% N   = number of array elements (odd or even)
% R   = relative sidelobe level in dB 
% nbar = number of near sidelobes
% 
% a   = row vector of array weights (steered towards ph0)
% dph = beamwidth in degrees 
%
% notes: calculates the Taylor n-bar distribution zeros,
%        maps them to the array zeros, and constructs the array 
%        polynomial using poly2
%
% see also gain1d, binomial, dolph, uniform, sector, taylorbw, taylor1p, ville

% Sophocles J. Orfanidis - 1999-2008 - www.ece.rutgers.edu/~orfanidi/ewa

function [a, dph] = taylor1n(d, ph0, N, R, nbar)

if nargin==0, help taylor1n; return; end

[B,Du] = taylorbw(R);                 % get Taylor's B-parameter and beamwidth

sigma = nbar / sqrt(B^2 + nbar^2);

u = zeros(1,N-1);

n = 1:nbar-1;    u(n) = sigma * sqrt(B^2 + n.^2); u(N-n) = -u(n);
n = nbar:N-nbar; u(n) = n;

psi = 2*pi*u/N;

z = exp(j*psi);

w = real(poly2(z));

a = steer(d, w, ph0);                  % steer towards ph0

a = a / norm(a);                       % normalize to unit norm - not really necessary

dps = 2 * pi * Du / N;    

dph = bwidth(d, ph0, dps);             % 3-dB width in phi-space














